@@ -51,7 +51,6 @@ package com.openexchange.ajp13;
 
 import java.io.ByteArrayOutputStream;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicReference;
@@ -360,9 +359,7 @@ public class AJPv13Response {
         final byte[] headers;
         {
             sink.reset();
-            final Iterator<String> iterator = servletResponse.getHeaderNames();
-            for (int i = 0; i < headersSize; i++) {
-                final String headerName = iterator.next();
+            for (final String headerName : servletResponse.getHeaderNames()) {
                 writeHeader(headerName, servletResponse.getHeader(headerName), sink);
             }
             headers = sink.toByteArray();
@@ -456,7 +453,14 @@ public class AJPv13Response {
         /*
          * No need to check against max package size cause it's a static package size of 6
          */
-        return closeConnection ? END_RESPONSE_CLOSE : END_RESPONSE_REUSE;
+        if (closeConnection) {
+            return END_RESPONSE_CLOSE;
+        } else if (AJPv13Config.isAJPModJK()) {
+            return END_RESPONSE_REUSE;
+        } else {
+            final boolean reuseConnection = AJPv13Server.getNumberOfOpenAJPSockets() <= AJPv13Config.getAJPMaxNumOfSockets();
+            return reuseConnection ? END_RESPONSE_REUSE : END_RESPONSE_CLOSE;
+        }
     }
 
     /**
