@@ -60,6 +60,7 @@ import javax.servlet.http.HttpSessionBindingEvent;
 import javax.servlet.http.HttpSessionBindingListener;
 import javax.servlet.http.HttpSessionContext;
 import com.openexchange.ajp13.AJPv13ServiceRegistry;
+import com.openexchange.ajp13.servlet.http.HttpSessionWrapper;
 import com.openexchange.config.ConfigTools;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.java.HashKeyMap;
@@ -88,9 +89,9 @@ public class HttpSessionWrapper implements HttpSession {
                 if (tmp < 0) {
                     final ConfigurationService service = AJPv13ServiceRegistry.getInstance().getService(ConfigurationService.class);
                     if (null == service) {
-                        tmp = ConfigTools.parseTimespanSecs("1W");
+                        tmp = (int) ConfigTools.parseTimespan("1W");
                     } else {
-                        tmp = ConfigTools.parseTimespanSecs(service.getProperty("com.openexchange.cookie.ttl", "1W"));
+                        tmp = (int) (ConfigTools.parseTimespan(service.getProperty("com.openexchange.cookie.ttl", "1W")) / 1000);
                     }
                     cookieTTL = tmp;
                 }
@@ -169,7 +170,7 @@ public class HttpSessionWrapper implements HttpSession {
     }
 
     @Override
-    public Enumeration<?> getAttributeNames() {
+    public Enumeration<String> getAttributeNames() {
         return new IteratorEnumeration(attributes.keySet().iterator());
     }
 
@@ -300,11 +301,11 @@ public class HttpSessionWrapper implements HttpSession {
         }
     }
 
-    private static class IteratorEnumeration implements Enumeration<Object> {
+    private static class IteratorEnumeration implements Enumeration<String> {
 
-        private final Iterator<?> iter;
+        private final Iterator<String> iter;
 
-        public IteratorEnumeration(final Iterator<?> iter) {
+        public IteratorEnumeration(final Iterator<String> iter) {
             this.iter = iter;
         }
 
@@ -314,7 +315,7 @@ public class HttpSessionWrapper implements HttpSession {
         }
 
         @Override
-        public Object nextElement() {
+        public String nextElement() {
             return iter.next();
         }
     }
